Stan Math Library: stan/math/prim/scal/fun/inv_logit.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_logit.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_INV_LOGIT_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_INV_LOGIT_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5
6 namespace stan {
7
8 namespace math {
9
50 template <typename T>
51 inline typename boost::math::tools::promote_args<T>::type
52 inv_logit(const T a) {
53 using std::exp;
54 return 1.0 / (1.0 + exp(-a));
55 }
56
57 }
58 }
59
60 #endif
61
stan
Definition: log_sum_exp.hpp:8
stan::math::inv_logit
fvar< T > inv_logit(const fvar< T > &x)
Definition: inv_logit.hpp:15
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10

[ Stan Home Page ] © 2011–2016, Stan Development Team.